/**
 * Converts a DOM node to an S-expression.
 *
 * @param {Node} node - The DOM node to convert.
 * @param {number} [space=2] - The number of spaces to use for indentation.
 * @return {string} The S-expression representation of the DOM node.
 *
 * @example
 * ```ts
 * import { JSDOM } from "jsdom";
 * import { nodeToSExpr } from "node-to-sexpr";
 *
 * const dom = new JSDOM(`
 *    <head>
 *       <title>Test Page</title>
 *   </head>
 *  <div id="foo" class="bar baz">
 *     <img src="https://example.com/image.png" />
 *    <a href="https://example.com">example.com</a>
 * </div>
 * `);
 * const sExpr = nodeToSExpr(document.body.parentElement!, 2);
 * console.log(sExpr);
 * ```
 */
declare function nodeToSExpr(node: Node, space?: number): string;

/**
 * Converts a document object into an S-expression.
 *
 * @param {number} space - The number of spaces to use for indentation. Defaults to 2.
 * @return {string} - The S-expression representation of the document.
 */
declare function documentToExpr(space?: number): string;
declare const _default: {
    nodeToSExpr: typeof nodeToSExpr;
    documentToExpr: typeof documentToExpr;
};

export { _default as default, documentToExpr, nodeToSExpr };
